load([DATA_DIR 'IIW/train_test_split.mat']);
%%
opts = get_default_opts();

opts.relation_field = 'darker';

% key point params
opts.kp_params.min_sep = 0.03;

% ROI params
params_ROI = [];
params_ROI.N = 8; % half patch size
params_ROI.mask_size = 32; % mask size for each blob (location of patch within the ROI) and ROI
params_ROI.blob_std = 0.1; % blob standard deviation
params_ROI.ROI_size = params_ROI.mask_size; % size of ROI 
params_ROI.I_size = 64;
params_ROI.BB_size = 32;
opts.params_ROI = params_ROI;

% DNN params
opts.DNN.model_def_file = './Models/IIW/ROI_smaller/deploy.prototxt';
opts.DNN.model_file = './Models/IIW/ROI_smaller/reflectance_net_iter_400000.caffemodel';
opts.DNN.which_layer = 'prob';
opts.DNN.Nbatch = 512;

% LS ranking params
ls_ranking_params = [];
ls_ranking_params.use_all_preds = true;
ls_ranking_params.use_uniform_weights = false;
ls_ranking_params.upper_bound = 0;
ls_ranking_params.lower_bound = log(1/255);

ls_ranking_params.ie_weight = 1;
ls_ranking_params.eq_weight = 5;
ls_ranking_params.ie_ratio = -log(2);
ls_ranking_params.prior_weight = 0.5;
ls_ranking_params.score_threshold = 0.2;

opts.ls_ranking_params = ls_ranking_params;

opts.intrinsic.blur_output = false;

opts.ls_ranking_params.solve_with_ratio = false;
opts.ls_ranking_params.ratio_solver_weight = 0.1;

%%
idx = testidx;

OUT_DIR = [RESULTS_DIR 'IIW/' datestr(now(),30) '/'];
if ~exist(OUT_DIR,'dir')
    mkdir(OUT_DIR);
end

for i=1:length(idx)
    out_name = sprintf([OUT_DIR 'ROI_ls_%d.mat'],i);
    
    if (exist(out_name,'file'))
        continue;
    else
        fprintf('processing image %s',out_name);
    end
    
    tic
    [I,filename] = load_iiw_image(idx(i));
    fprintf('processing %d\n',idx(i));

    [R,S,points_outputs,comps_outputs] = do_intrinsic_decomposition(I,opts);
    toc
    
    %save(sprintf([OUT_DIR 'ROI_ls_%d.mat'],i),'R','S','points_outputs','comps_outputs','opts');
    data = [];
    data.R = R;
    data.S = S;
    data.points_outputs = points_outputs;
    data.comps_outputs = comps_outputs;
    data.opts = opts;
    parsave(out_name,data);
    
    subplot(2,2,1); showim(I); title('image');
    subplot(2,2,2); showim(R); title('reflectance');
    subplot(2,2,3); showim(S); title('shading');
    drawnow;
end
