function generate_MIT_annotations_simple(opts)
DATA_DIR = opts.paths.DATA_DIR;
load([DATA_DIR 'MIT/data.mat']);

OUT_DIR = [DATA_DIR opts.MIT_gen.OUT_DIR];
if ~exist(OUT_DIR,'dir')
    mkdir(OUT_DIR);
end

delta_depth = opts.MIT_gen.delta_depth;
delta_R = opts.MIT_gen.delta_R;
kp_params = opts.MIT_gen.kp_params;

num_models = length(masks);
%%
for i=1:num_models
    fprintf('processing %d\n',i);
    for l=1:length(lights_images{i})
        %%
        tic
        

        I = im2uint8(lights_images{i}{l});
        mask = im2uint8(masks{i});

        depth = gt_Z{i};
        R = mean(im2uint8(gt_R{i}),3);

        % extract keypoints
        if kp_params.use_multiscale
            % finest scale points
            [points,sp_data] = extract_key_points(I,kp_params);
            [~,ij] = get_point_pairs_ms(I,kp_params,points,sp_data);
        elseif kp_params.use_random
            [points,sp_data] = extract_key_points(I,kp_params);
            ij = randi(length(points),kp_params.num_pairs,2);
            ij = unique(ij,'rows');
        else
            [points,sp_data] = extract_key_points(I,kp_params);
            [~,ij] = get_point_pairs(sp_data,true);
        end

        % post process super pixels - prune and choose mode label
        for p=1:length(points)
            sp_labels = mask(sp_data.spidx{p});

            % discard super pixels with a majority of unlabeled pixels
            if mode(sp_labels)==0
                points(p).opaque = 0;
            end
        end

        % now process all neighbors and decide which one is in front, if at all
        comps = struct('point1',-1,'point2',-1,'closer',-1,'closer_score',-1,'darker',-1,'darker_score',-1);

        t = 1;
        for p=1:length(points)
            neighbors = ij(ij(:,1)==p,2)';
            if isempty(neighbors)
                continue;
            end
            for q=neighbors
                if points(p).opaque && points(q).opaque
                    % do raw depth at point
                    c = [];
                    c.point1 = p;
                    c.point2 = q;
                    c.closer = 'E';
                    c.closer_score = -1;
                    c.darker = 'E';
                    c.darker_score = -1;

                    p_depth = depth(points(p).ind);
                    q_depth = depth(points(q).ind);

                    p_R = R(points(p).ind);
                    q_R = R(points(q).ind);
                    
                    if (p_depth/q_depth) > (1.0 + delta_depth)
                        c.closer = '2';
                        c.closer_score = 1;
                    elseif (q_depth/p_depth) > (1.0 + delta_depth)
                        c.closer = '1';
                        c.closer_score = 1;
                    else
                        c.closer = 'E';
                        c.closer_score = 1;
                    end
                    
                    if (p_R/q_R) > (1.0 + delta_R)
                        c.darker = '2';
                        c.darker_score = 1;
                    elseif (q_R/p_R) > (1.0 + delta_R)
                        c.darker = '1';
                        c.darker_score = 1;
                    else
                        c.darker = 'E';
                        c.darker_score = 1;
                    end

                    if ~isempty(c)
                        comps(t) = c;
                        t=t+1;
                    end
                end
            end
        end

        if opts.viz
            subplot(2,1,1); show_annotations(I,points,comps,'closer','closer_score');
            subplot(2,1,2); show_annotations(I,points,comps,'darker','darker_score');
            drawnow;
        end

        filename = sprintf([OUT_DIR '%d_%d_comps.mat'],i,l);
        save(filename,'points','comps','opts');
        toc
    end
end
