function generate_bsds_annotations_simple(opts)

DATA_DIR = opts.paths.DATA_DIR;
CODE_DIR = opts.paths.CODE_DIR;
addpath(genpath([CODE_DIR 'data_generation/fgcode']));
addpath(genpath([CODE_DIR 'data_generation/segbench']));
[test_data, train_data] = generate_bsds_data_new(opts);

if opts.bsds_gen.train
    dataset = train_data;
    OUT_DIR = [DATA_DIR opts.bsds_gen.OUT_DIR 'train/'];
else
  dataset = test_data;
  OUT_DIR = [DATA_DIR opts.bsds_gen.OUT_DIR 'test/'];
end
num_images = length(dataset); 

% not sure
if ~exist(OUT_DIR,'dir')
mkdir(OUT_DIR);
end

kp_params = opts.bsds_gen.kp_params;

%%
idx = 1:num_images;
for i=1:length(idx)
    %%
    tic
    fprintf('processing %s\n', dataset{i}.name);
        
    I = dataset{i}.image; % get image

    % extract keypoints
    if kp_params.use_multiscale
        % finest scale points
        [points,sp_data] = extract_key_points(I,kp_params);
        [~,ij] = get_point_pairs_ms(I,kp_params,points,sp_data);
    elseif kp_params.use_random
        [points,sp_data] = extract_key_points(I,kp_params);
        ij = randi(length(points),kp_params.num_pairs,2);
        ij = unique(ij,'rows');
    else
        [points,sp_data] = extract_key_points(I,kp_params);
        [~,ij] = get_point_pairs(sp_data,true);
    end
    
    % now process all neighbors and decide which one is in front, if at all
    comps = struct('point1',-1,'point2',-1,'closer',-1,'closer_score',-1);
   
    t = 1;
    for p=1:length(points)
        neighbors = ij(ij(:,1)==p,2)';
        if isempty(neighbors)
            continue;
        end
        for q=neighbors
            c = [];
            c.point1 = p;
            c.point2 = q;
            % somewhere here this needs to be done
            class_label = compute_class_label([points(p).i points(p).j], [points(q).i points(q).j], dataset{i}.seg, dataset{i}.fgmap);
            if class_label == 0 % no contour
                c.closer = 'E';
            end
            if class_label == 1 % p is figure
              c.closer = '1';

            end
            if class_label == 2 % q is figure
              c.closer = '2';

            end
            if class_label == -1
                c.closer = 'E';
                c.closer_score = 0;
            else
                c.closer_score = 1;
            end

            if ~isempty(c)
                comps(t).point1 = c.point1;
                comps(t).point2 = c.point2;
                comps(t).closer = c.closer;
                comps(t).closer_score = c.closer_score;
                t=t+1;
            end
            
        end
    end

    
    if opts.viz
         show_annotations(I,points,comps,'closer','closer_score');
        drawnow;
        keyboard;
    end

    filename = sprintf([OUT_DIR '%d_comps.mat'],idx(i));
    img_id = dataset{i}.name;
    save(filename,'points','comps','img_id','opts');
    toc
end

