function generate_nyu_annotations_simple(opts)
DATA_DIR = opts.paths.DATA_DIR;
if ~exist('images','var')
    load([DATA_DIR 'NYU/nyu_depth_v2_labeled.mat']);
end

num_images = size(images,4);


OUT_DIR = [DATA_DIR opts.NYU_gen.OUT_DIR];
if ~exist(OUT_DIR,'dir')
    mkdir(OUT_DIR);
end

delta_raw = opts.NYU_gen.delta_raw;
kp_params = opts.NYU_gen.kp_params;

%%
idx = 1:num_images;
for i=1:length(idx)
    %%
    tic
    fprintf('processing %d\n',idx(i));
        
    I = images(:,:,:,idx(i)); % get image
    img_instances = get_instance_masks(labels(:,:,idx(i)),instances(:,:,idx(i))); % get instance map
    segs = zeros(size(I,1),size(I,2));
    for p=1:size(img_instances,3)
        segs(img_instances(:,:,p)) = p;
    end
 
    depth = depths(:,:,idx(i));
    
    % extract keypoints
    if kp_params.use_multiscale
        % finest scale points
        [points,sp_data] = extract_key_points(I,kp_params);
        [~,ij] = get_point_pairs_ms(I,kp_params,points,sp_data);
    elseif kp_params.use_random
        [points,sp_data] = extract_key_points(I,kp_params);
        ij = randi(length(points),kp_params.num_pairs,2);
        ij = unique(ij,'rows');
    else
        [points,sp_data] = extract_key_points(I,kp_params);
        [~,ij] = get_point_pairs(sp_data,true);
    end
    
    % post process super pixels - prune and choose mode label
    for p=1:length(points)
        sp_labels = segs(sp_data.spidx{p});
        
        % discard super pixels with a majority of unlabeled pixels
        points(p).label = mode(sp_labels);
        if points(p).label==0
            points(p).opaque = 0;
        end
    end
    
    % now process all neighbors and decide which one is in front, if at all
    comps = struct('point1',-1,'point2',-1,'closer',-1,'closer_score',-1,'closer_raw',-1,'closer_score_raw',-1);
   
    t = 1;
    for p=1:length(points)
        neighbors = ij(ij(:,1)==p,2)';
        if isempty(neighbors)
            continue;
        end
        for q=neighbors
            if points(p).opaque && points(q).opaque
                % do raw depth at point
                c = [];
                c.point1 = p;
                c.point2 = q;
                c.closer = 'E';
                c.closer_score = -1;


                p_depth = depth(points(p).ind);
                q_depth = depth(points(q).ind);

                if (p_depth/q_depth) > (1.0 + delta_raw)
                    c.closer_raw = '2';
                    c.closer_score_raw = 1;
                elseif (q_depth/p_depth) > (1.0 + delta_raw)
                    c.closer_raw = '1';
                    c.closer_score_raw = 1;
                else
                    c.closer_raw = 'E';
                    c.closer_score_raw = 1;
                end

                % now do label aware comparison
                if points(p).opaque && points(q).opaque && points(p).label==points(q).label
                    c.closer = 'E';
                    c.closer_score = 1;
                else
                    c.closer = c.closer_raw;
                    c.closer_score = 1;
                end


                if ~isempty(c)
                    comps(t) = c;
                    t=t+1;
                end
            end
        end
    end
    
    if opts.viz
        subplot(2,1,1); show_annotations(I,points,comps,'closer','closer_score');
        subplot(2,1,2); show_annotations(I,points,comps,'closer_raw','closer_score_raw');
        drawnow;
    end
    
    filename = sprintf([OUT_DIR '%d_comps.mat'],idx(i));
    save(filename,'points','comps','opts');
    toc
end
