%IN_DIR = [RESULTS_DIR 'NYU/20150419T153455/']; % change this to whatever results you want
IN_DIR = [RESULTS_DIR 'IIW/20150413T231134/'];
task_type = 'reflectance'; % options: 'reflectance', 'depth'

num_images = 50;

D = cell(num_images,1);
points = cell(num_images,1);
comps = cell(num_images,1);
%%
for i=1:num_images

    load(sprintf([IN_DIR 'ROI_ls_%d.mat'],i));
    %%
    tic
    if (strcmp(task_type,'reflectance'))
        [D{i},points{i},comps{i}] = deal(RR,ppoints_outputs,ccomps_outputs);
    elseif (strcmp(task_type,'depth'))
        [D{i},points{i},comps{i}] = deal(data.Z,data.points_outputs,data.comps_outputs);
    else
        error('unknown task type');
    end
    toc
   
end

%% analyze
angles = [];
distances = [];
preds = [];
for i=1:num_images
    p1 = [comps{i}.point1];
    p2 = [comps{i}.point2];

    dxs = [points{i}(p1).j] - [points{i}(p2).j];
    dys = [points{i}(p1).i] - [points{i}(p2).i];

    flag = rand(length(p1),1)>0.5;
    
    dxs(flag) = dxs(flag)*-1;
    dys(flag) = dys(flag)*-1;
    
    angles = [angles; atan2(dys(:),dxs(:))];
    distances = [distances; sqrt(dxs(:).^2 + dys(:).^2)];
    
    predictions = [comps{i}.pred_prob]';
    t = predictions(flag,2);
    predictions(flag,2) = predictions(flag,3);
    predictions(flag,3) = t;
    
    preds = [preds; predictions];
end


%% styling
c_eq = [0.5,0.5,0.5];
c_ie1 = [0.9,0.4,0.1];
c_ie2 = [0,0.4,1];


%%
close all;

nbins = 50;
edges = linspace(-pi,pi,nbins);
[N,bins] = histc(angles,edges);
%[N,bins] = histcountsn(angles+pi,{edges},1);

%
eq_hist = accumarray(bins(:),preds(:,1),[],@mean);
ie1_hist = accumarray(bins(:),preds(:,2),[],@mean);
ie2_hist = accumarray(bins(:),preds(:,3),[],@mean);

se_eq_hist = sqrt(eq_hist.*(1-eq_hist))./sqrt(N);
se_ie1_hist = sqrt(ie1_hist.*(1-ie1_hist))./sqrt(N);
se_ie2_hist = sqrt(ie2_hist.*(1-ie2_hist))./sqrt(N);

m = N>50;
edges(~m) = [];
N(~m) = [];
eq_hist(~m) = [];
se_eq_hist(~m) = [];
ie1_hist(~m) = [];
se_ie1_hist(~m) = [];
ie2_hist(~m) = [];
se_ie2_hist(~m) = [];

figure('Color',[1,1,1]);

c = c_eq;
shadedErrorBar_custom2_polar(edges,eq_hist,se_eq_hist,{'markerfacecolor',c,'color',c,'LineWidth',1,'markersize',5},1); hold on;

c = c_ie1;
shadedErrorBar_custom2_polar(edges,ie1_hist,se_ie1_hist,{'markerfacecolor',c,'color',c,'LineWidth',1,'markersize',5},1); hold on;

c = c_ie2;
shadedErrorBar_custom2_polar(edges,ie2_hist,se_ie2_hist,{'markerfacecolor',c,'color',c,'LineWidth',1,'markersize',5},1); hold on;

%{
h = polar(edges(:),eq_hist(:)); hold on;
set(h, 'Color', c_eq);
h = polar(edges(:),ie1_hist(:));
set(h, 'Color', c_ie1);
h = polar(edges(:),ie2_hist(:)); hold off;
set(h, 'Color', c_ie2);
%}

PublishizePlot_phillip;
%
export_fig(fullfile(RESULTS_DIR,'figures','net_psychophysics',sprintf('relative_orientation_%s.pdf',task_type)));

%%
close all;

nbins = 40;
max_dist = 510;
edges = linspace(0,max_dist,nbins);
[N,bins] = histc(distances,edges);

eq_hist = accumarray(bins(:),preds(:,1),[nbins,1],@mean);
ie1_hist = accumarray(bins(:),preds(:,2),[nbins,1],@mean);
ie2_hist = accumarray(bins(:),preds(:,3),[nbins,1],@mean);

se_eq_hist = sqrt(eq_hist.*(1-eq_hist))./sqrt(N);
se_ie1_hist = sqrt(ie1_hist.*(1-ie1_hist))./sqrt(N);
se_ie2_hist = sqrt(ie2_hist.*(1-ie2_hist))./sqrt(N);

m = N>50;
edges(~m) = [];
N(~m) = [];
eq_hist(~m) = [];
se_eq_hist(~m) = [];
ie1_hist(~m) = [];
se_ie1_hist(~m) = [];
ie2_hist(~m) = [];
se_ie2_hist(~m) = [];

figure('Color',[1,1,1]);


c = c_eq;
shadedErrorBar_custom2(edges,eq_hist,se_eq_hist,{'-','markerfacecolor',c,'color',c,'LineWidth',1,'markersize',5},1); hold on;

c = c_ie1;
shadedErrorBar_custom2(edges,ie1_hist,se_ie1_hist,{'-','markerfacecolor',c,'color',c,'LineWidth',1,'markersize',5},1); hold on;

c = c_ie2;
shadedErrorBar_custom2(edges,ie2_hist,se_ie2_hist,{'-','markerfacecolor',c,'color',c,'LineWidth',1,'markersize',5},1); hold on;

%legend({'P(A=B)','P(A<B)','P(A>B)'});

%{
plot(edges(:),eq_hist(:),'g'); hold on;
plot(edges(:),ie1_hist(:),'b');
plot(edges(:),ie2_hist(:),'r'); hold off;
%}

PublishizePlot_phillip;

grid on; axis('square');
%
export_fig(fullfile(RESULTS_DIR,'figures','net_psychophysics',sprintf('distance_%s.pdf',task_type)));

