function [Z,points,comps] = do_depth_from_image_MS(I,opts)
%% extract points, pairs and superpixel data
kp_params = opts.kp_params;

%% get second order neighbors for comparison, first order for smoothness

if opts.kp_params.use_multiscale
    % finest scale points
    [points,sp_data] = extract_key_points(I,kp_params);
    [comps,~] = get_point_pairs_ms(I,kp_params,points,sp_data);
elseif kp_params.use_random
    [points,sp_data] = extract_key_points(I,kp_params);
    ij = randi(length(points),kp_params.num_pairs,2);
    ij = unique(ij,'rows');
    comps = [];
    for t=1:size(ij,1)
        comps(t).point1 = ij(t,1);
        comps(t).point2 = ij(t,2);
    end
else
    [points,sp_data] = extract_key_points(I,kp_params);
    [comps,~] = get_point_pairs(sp_data,true);
end
[~,ij] = get_point_pairs(sp_data,false);

% try doubling the comps
% num_comps = length(comps);
% for t=1:length(comps)
%     c = comps(t);
%     temp = c.point1;
%     c.point1 = c.point2;
%     c.point2 = temp;
%     
%     comps(num_comps+t) = c;
% end

%% get dnn estimates
if isfield(opts,'use_gt') && opts.use_gt
    [preds,fs] = get_gt_annotations_depth(I,points,comps,opts);
else
    [preds,fs] = infer_ordinal_relations_conv(I,points,comps,opts);
end
for t=1:length(preds)
    if (preds(t)==0)
        comps(t).closer = 'E';
    elseif (preds(t)==1)
        comps(t).closer = '1';
    else
        comps(t).closer = '2';
    end
    comps(t).pred_prob = fs(:,t);
    comps(t).closer_score = max(comps(t).pred_prob);
end

%% build smoothness term
I = im2double(I); I(I<=0) = 1/255; I(I>=1) = 1;

% get log mean luminance at each super pixel
npoints = length(points);
L = zeros(npoints,1);
t = mean(I,3);
for k=1:npoints
    L(k) = mean(t(sp_data.spidx{k}));
end
 
Lij = double(L(ij(:,1))-L(ij(:,2)));

ij = double(ij);

% build shading smoothness term
num_pairs = size(ij,1);
pair_inds = 1:num_pairs;
Ap = sparse([pair_inds(:); pair_inds(:)],[ij(:,1);ij(:,2)],[ones(num_pairs,1); -1*ones(num_pairs,1)],num_pairs,npoints);
lambda = opts.depth_params.image_smoothness_var;
W = sparse(1:num_pairs,1:num_pairs,exp(-(0.5/lambda^2)*Lij.^2),num_pairs,num_pairs);
A_prior = opts.ls_ranking_params.prior_weight*Ap'*W*Ap;
b_prior = zeros(npoints,1);

Zs = do_ls_ranking(A_prior,b_prior,points,comps,opts);

% flood fill super pixels with estimated reflectance and shading
% Zs = exp(Zs);
Z = zeros(size(I,1),size(I,2));

% flood fill super pixels
for i=1:npoints
    Z(sp_data.spidx{i}) = Zs(i);
end
