function [Xs] = do_ls_ranking(A_prior,b_prior,points,comps,opts)
if isfield(opts.ls_ranking_params,'solve_with_ratio') && opts.ls_ranking_params.solve_with_ratio
    Xs = do_ls_ranking_with_r(A_prior,b_prior,points,comps,opts);
    return;
end

% do least squares rank aggregation
% comps should have a field named "pred_prob", a 1x3 matrix for the
% probabilites of 'E','1' and '2'
%
% solves min_x x'*A_prior*x + soft equality and inequality constraints s.t
% x>lb and x<ub
relation_field = opts.relation_field;
relation_field_score = opts.relation_field_score;

params = opts.ls_ranking_params;
lb = params.lower_bound;
ub = params.upper_bound;

%% get equality and inequality pairs
if params.use_all_preds
    ie_pairs = zeros(length(comps)*2,2);
    eq_pairs = zeros(length(comps),2);
    eq_ws = zeros(length(comps),1);
    ie_ws = zeros(length(comps)*2,1);
    for t=1:length(comps)
        c = comps(t); 
        p1 = points(c.point1);
        p2 = points(c.point2);

        if ~p1.opaque || ~p2.opaque
            continue
        end

        eq_pairs(t,:) = [p1.id, p2.id];
        eq_ws(t) = c.pred_prob(1);

        ie_pairs(t,:) = [p2.id, p1.id];
        ie_ws(t) = c.pred_prob(2);

        ie_pairs(length(comps)+t,:) = [p1.id, p2.id];
        ie_ws(length(comps)+t) = c.pred_prob(3);
    end
else
    ie_pairs = []; eq_pairs = [];
    ie_ws = []; eq_ws = [];
    for t=1:length(comps)
        c = comps(t); 
        p1 = points(c.point1);
        p2 = points(c.point2);

        if c.(relation_field_score)>0
            if c.(relation_field)=='E'
                eq_pairs = [eq_pairs; p1.id, p2.id];
                eq_ws = [eq_ws; c.(relation_field_score)];
            elseif c.(relation_field)=='1'
                ie_pairs = [ie_pairs; p2.id, p1.id];
                ie_ws = [ie_ws; c.(relation_field_score)];
            else
                ie_pairs = [ie_pairs; p1.id, p2.id];
                ie_ws = [ie_ws; c.(relation_field_score)];
            end
        end
    end
end

if isfield(params,'score_threshold')
    ie_ws(ie_ws<params.score_threshold) = 0;
    eq_ws(eq_ws<params.score_threshold) = 0;
end

if params.use_uniform_weights
    if params.use_all_preds
        warning('If using all predictions then using uniform weights is a bad idea.');
    end
    ie_ws = ones(size(ie_ws));
    eq_ws = ones(size(eq_ws));
end

%% build and solve quadratic system
npoints = length(points);

ie_pairs = double(ie_pairs);
eq_pairs = double(eq_pairs);

% build ineqaulity matrix
ie_inds = 1:size(ie_pairs,1);
Aie = sparse([ie_inds(:); ie_inds(:)],[ie_pairs(:,1); ie_pairs(:,2)],[-ie_ws.*ones(size(ie_pairs,1),1); ie_ws.*ones(size(ie_pairs,1),1)],size(ie_pairs,1),npoints);
bie = params.ie_ratio.*ones(size(ie_pairs,1),1); % best setting so far

% build equality matrix
eq_inds = 1:size(eq_pairs,1);
Aeq = sparse([eq_inds(:); eq_inds(:)],[eq_pairs(:,1); eq_pairs(:,2)],[eq_ws.*ones(size(eq_pairs,1),1); -eq_ws.*ones(size(eq_pairs,1),1)],size(eq_pairs,1),npoints);
beq = zeros(size(eq_pairs,1),1);

% solve system
A = (params.eq_weight*(Aeq'*Aeq) + params.ie_weight*(Aie'*Aie) + A_prior);
b = (params.eq_weight*(Aeq'*beq) + params.ie_weight*(Aie'*bie) + b_prior);
Xs = quadprog(A,-b,[],[],[],[],lb.*ones(npoints,1),ub.*ones(npoints,1));