%% initialize
% make sure piotr dollar's toolbox and vlfeat are in the path
init_setup

if ~exist('images','var')
    load([DATA_DIR 'NYU/nyu_depth_v2_labeled.mat']);
    load([DATA_DIR 'NYU/splits_nyu.mat']);
end

idx = testNdxs;

% load image and crop (20 pixels from each side, as in the paper)
i=112;
I = (images(:,:,:,idx(i)));
I = I(20:end-20,20:end-20,:);
gtZ = depths(:,:,idx(i));
gtZ = gtZ(20:end-20,20:end-20);
%%
opts = get_default_opts();

opts.relation_field = 'closer';
opts.relation_field_score = 'closer_score';

% key point params
opts.kp_params.min_sep = 0.03;
opts.kp_params.use_multiscale = true;
opts.kp_params.use_random = true;
opts.kp_params.num_pairs = 5000;

% ROI params
params_ROI = [];
params_ROI.N = 8; % half patch size
params_ROI.mask_size = 32; % mask size for each blob (location of patch within the ROI) and ROI
params_ROI.blob_std = 0.1; % blob standard deviation
params_ROI.ROI_size = params_ROI.mask_size; % size of ROI 
params_ROI.I_size = 64;
params_ROI.BB_size = 32;
opts.params_ROI = params_ROI;

% DNN params
opts.DNN.model_def_file = './Models/NYU/ROI_ms_raw/deploy_fast.prototxt';
opts.DNN.model_def_file_I = './Models/NYU/ROI_ms_raw/deploy_I.prototxt';
opts.DNN.model_file = './Models/NYU/ROI_ms_raw/depth_net_ms_raw_iter_400000.caffemodel';

opts.DNN.which_layer = 'prob';
opts.DNN.which_layer_I = 'norm2_I';
opts.DNN.Nbatch = 512;

% LS ranking params
ls_ranking_params = [];
ls_ranking_params.use_all_preds = true;
ls_ranking_params.use_uniform_weights = false;
ls_ranking_params.upper_bound = 10;
ls_ranking_params.lower_bound = 0;

ls_ranking_params.ie_weight = 1;
ls_ranking_params.eq_weight = 5;
ls_ranking_params.ie_ratio = -0.1;
ls_ranking_params.prior_weight = 1;

opts.ls_ranking_params = ls_ranking_params;

opts.depth_params.image_smoothness_var = 0.1; % make it less than 0.1 to make result really sharp

opts.ls_ranking_params.solve_with_ratio = true;
opts.ls_ranking_params.ratio_solver_ie_var = 4;
opts.ls_ranking_params.ratio_solver_eq_var = 0.1;

% uncomment this to use ground truth annotations
% opts.use_gt = true;
% opts.gtZ = gtZ;
% opts.delta = 0.1;
%%
tic
[Z,points,comps] = do_depth_from_image(I,opts);
toc
%%

subplot(2,2,1); showim(I); title('image');
subplot(2,2,2); showim(Z); title('estimated depth'); colormap jet;
subplot(2,2,3); show_annotations(I,points,comps,'closer','closer_score');
subplot(2,2,4); showim(gtZ); title('gt'); colormap jet;

mean( ( (Z(:)-mean(Z(:)) - (gtZ(:)-mean(gtZ(:)))) ).^2)
