function [P,M] = extract_patches_ms_from_comps(I,points,comps,opts)
%%
M = uint8([]);
P1 = uint8([]);
P2 = uint8([]);
BB = uint8([]);

params = opts.params_MS;

num_scales = params.num_scales;

N = params.N; % half patch size
[xx,yy] = meshgrid(linspace(0,1,params.mask_size),linspace(0,1,params.mask_size));
blob_std = params.blob_std;

tic
% create image at all scales
I_s = cell(num_scales,1);
I_pad = cell(num_scales,1);
pad_h = cell(num_scales,1);
pad_w = cell(num_scales,1);
I = im2double(I);
for s=1:num_scales
    I_s{s} = imresize(I,2^(-(s-1)),'bilinear');
    
    % get largest padding necessary and then some
    pad_h{s} = size(I_s{s},1);
    pad_w{s} = size(I_s{s},2);

    I_pad{s} = padarray(I_s{s},[pad_h{s} pad_w{s}],'both');
end

% extract patches at all scales for each point
P = cell(num_scales,1);
rects = cell(num_scales,1);
is = cell(num_scales,1);
js = cell(num_scales,1);

npoints = length(points);
for s=1:num_scales
    is{s} = round([points.y]*size(I_s{s},1));
    js{s} = round([points.x]*size(I_s{s},2));
    
    P{s} = zeros(N*2+1,N*2+1,size(I,3),npoints);
    rects{s} = zeros(npoints,4);
    for p=1:npoints
        i = is{s}(p);
        j = js{s}(p);
        
        rects{s}(p,:) = [i-N,j-N,i+N,j+N];
        rect = rects{s}(p,:);
        P{s}(:,:,:,p) = I_pad{s}(pad_h{s}+1+(rect(1):rect(3)),pad_w{s}+1+(rect(2):rect(4)),:);
    end
end
toc

tic
% now generate masks for each pair
for t=1:length(comps)
    c = comps(t);
    
    % get the two points to compare
    p1 = c.point1;
    p2 = c.point2;

    for s=1:num_scales
        i1 = is{s}(p1);
        j1 = js{s}(p1);
        
        i2 = is{s}(p2);
        j2 = js{s}(p2);
        
        % now build mask, coordinate frame is point 1
        rect = rects{s}(p1,:);
        h = rect(3)-rect(1);
        w = rect(4)-rect(2);
        cy1 = (i1-rect(1))/h;
        cx1 = (j1-rect(2))/w;
        mask1 = exp(-0.5/blob_std.^2*((yy-cy1).^2 + (xx-cx1).^2));
        cy2 = (i2-rect(1))/h;
        cx2 = (j2-rect(2))/w;
        mask2 = exp(-0.5/blob_std.^2*((yy-cy2).^2 + (xx-cx2).^2));

        if opts.viz
            subplot(num_scales+1,4,(s-1)*4+1); showim(P{s}(:,:,:,p1));
            subplot(num_scales+1,4,(s-1)*4+2); showim(mask1,[0 1]);
            subplot(num_scales+1,4,(s-1)*4+3); showim(P{s}(:,:,:,p2));
            subplot(num_scales+1,4,(s-1)*4+4); showim(mask2,[0 1]);
        end

    end
    
    if opts.viz
        subplot(num_scales+1,4,num_scales*4 + (1:4)); showim(I); axis image;
        hold on;
        i1 = is{1}(p1);
        j1 = js{1}(p1);

        i2 = is{1}(p2);
        j2 = js{1}(p2);
        plot(j1,i1,'rO');
        plot(j2,i2,'gO');
        hold off;
        drawnow;
    end
end
toc

% 
% 
% for t=1:length(comps)
%     c = comps(t);
%     
%     % get the two points to compare
%     p1 = points(c.point1);
%     p2 = points(c.point2);
% 
%     i1 = p1.i;
%     j1 = p1.j;
% 
%     i2 = p2.i;
%     j2 = p2.j;
% 
%     % get rect for first patch [top, left, bottom, right]
%     rect1 = [i1-N,j1-N,i1+N,j1+N];
%     rect2 = [i2-N,j2-N,i2+N,j2+N];
% 
%     % extract bounding box of two patches
%     bb_rect = [min(rect1(1:2),rect2(1:2))-N/4, max(rect1(3:4),rect2(3:4))+N/4];
% 
%     % make sure it's square (while centered)
%     bb_w = bb_rect(4)-bb_rect(2);
%     bb_h = bb_rect(3)-bb_rect(1);
% 
%     if bb_h>bb_w
%         bb_rect(2) = bb_rect(2)-floor((bb_h-bb_w)/2);
%         bb_rect(4) = bb_rect(4)+ceil((bb_h-bb_w)/2);
%     else
%         bb_rect(1) = bb_rect(1)-floor((bb_w-bb_h)/2);
%         bb_rect(3) = bb_rect(3)+ceil((bb_w-bb_h)/2);
%     end
% 
%     % get width and height
%     bb_w = bb_rect(4)-bb_rect(2);
%     bb_h = bb_rect(3)-bb_rect(1);
% 
%     I_BB = I_pad(pad_h+(1+bb_rect(1):bb_rect(3)),pad_w+(1+bb_rect(2):bb_rect(4)),:);
%     I_BB = imresize(I_BB,[params.BB_size,params.BB_size],'bilinear');
%     I_ROI = xx>(bb_rect(2)/size(I,2)) & xx<(bb_rect(4)/size(I,2)) & yy>(bb_rect(1)/size(I,1)) & yy<(bb_rect(3)/size(I,1));
%     I_P1 = I_pad(pad_h+(1+rect1(1):rect1(3)),pad_w+(1+rect1(2):rect1(4)),:);
%     I_P2 = I_pad(pad_h+(1+rect2(1):rect2(3)),pad_w+(1+rect2(2):rect2(4)),:);
% 
%     % now build mask
%     cy1 = (i1-bb_rect(1))/bb_h;
%     cx1 = (j1-bb_rect(2))/bb_w;
%     mask1 = exp(-0.5/blob_std.^2*((yy-cy1).^2 + (xx-cx1).^2));
%     cy2 = (i2-bb_rect(1))/bb_h;
%     cx2 = (j2-bb_rect(2))/bb_w;
%     mask2 = exp(-0.5/blob_std.^2*((yy-cy2).^2 + (xx-cx2).^2));
% 
%     M(:,:,:,end+1) = cat(3,im2uint8(mask1),im2uint8(mask2),im2uint8(I_ROI));
%     P1(:,:,:,end+1) = I_P1;
%     P2(:,:,:,end+1) = I_P2;
%     BB(:,:,:,end+1) = I_BB;
%     
%     if opts.viz
%         subplot(3,2,1); showim(I); axis image;
%         hold on;
%         plot(j1,i1,'rO');
%         plot(j2,i2,'gO');
%         rectangle('Position',[rect1(2) rect1(1), rect1(4)-rect1(2), rect1(3)-rect1(1)]);
%         rectangle('Position',[rect2(2) rect2(1), rect2(4)-rect2(2), rect2(3)-rect2(1)]);
%         rectangle('Position',[bb_rect(2) bb_rect(1), bb_rect(4)-bb_rect(2), bb_rect(3)-bb_rect(1)]);
%         hold off;
%         subplot(3,2,2); showim(I_ROI);
%         subplot(3,2,3); showim(mask1); title('point1')
%         subplot(3,2,4); showim(mask2); title('point2');
%         subplot(3,2,5); showim(cat(2,I_P1,I_P2)); title('P1P2');
%         subplot(3,2,6); showim(I_BB); title('BB');
%         drawnow;
%     end
% end
% 
% M = M(:,:,:,2:end);
% P1 = P1(:,:,:,2:end);
% P2 = P2(:,:,:,2:end);
% BB = BB(:,:,:,2:end);