function [P1,P2,BB,M] = extract_patches_roi_from_comps(I,points,comps,opts)

M = uint8([]);
P1 = uint8([]);
P2 = uint8([]);
BB = uint8([]);

params = opts.params_ROI;

N = params.N;
[xx,yy] = meshgrid(linspace(0,1,params.mask_size),linspace(0,1,params.mask_size));
blob_std = params.blob_std;

 % get largest padding necessary and then some
pad_h = size(I,1);
pad_w = size(I,2);

I_pad = padarray(I,[pad_h pad_w],'both');



for t=1:length(comps)
    c = comps(t);
    
    % get the two points to compare
%     p1 = points([points.id]==c.point1);
%     p2 = points([points.id]==c.point2);
    p1 = points(c.point1);
    p2 = points(c.point2);

    i1 = p1.i;
    j1 = p1.j;

    i2 = p2.i;
    j2 = p2.j;

    % get rect for first patch [top, left, bottom, right]
    rect1 = [i1-N,j1-N,i1+N,j1+N];
    rect2 = [i2-N,j2-N,i2+N,j2+N];

    % extract bounding box of two patches
    bb_rect = [min(rect1(1:2),rect2(1:2))-N/4, max(rect1(3:4),rect2(3:4))+N/4];

    % make sure it's square (while centered)
    bb_w = bb_rect(4)-bb_rect(2);
    bb_h = bb_rect(3)-bb_rect(1);

    if bb_h>bb_w
        bb_rect(2) = bb_rect(2)-floor((bb_h-bb_w)/2);
        bb_rect(4) = bb_rect(4)+ceil((bb_h-bb_w)/2);
    else
        bb_rect(1) = bb_rect(1)-floor((bb_w-bb_h)/2);
        bb_rect(3) = bb_rect(3)+ceil((bb_w-bb_h)/2);
    end

    % get width and height
    bb_w = bb_rect(4)-bb_rect(2);
    bb_h = bb_rect(3)-bb_rect(1);

    I_BB = I_pad(pad_h+(1+bb_rect(1):bb_rect(3)),pad_w+(1+bb_rect(2):bb_rect(4)),:);
%     I_BB = imresize(I_BB,[params.BB_size,params.BB_size],'bilinear');
    I_BB = imResample(I_BB,32/bb_w);
    I_ROI = xx>(bb_rect(2)/size(I,2)) & xx<(bb_rect(4)/size(I,2)) & yy>(bb_rect(1)/size(I,1)) & yy<(bb_rect(3)/size(I,1));
    I_P1 = I_pad(pad_h+(1+rect1(1):rect1(3)),pad_w+(1+rect1(2):rect1(4)),:);
    I_P2 = I_pad(pad_h+(1+rect2(1):rect2(3)),pad_w+(1+rect2(2):rect2(4)),:);

    % now build mask
    cy1 = (i1-bb_rect(1))/bb_h;
    cx1 = (j1-bb_rect(2))/bb_w;
    mask1 = exp(-0.5/blob_std.^2*((yy-cy1).^2 + (xx-cx1).^2));
    cy2 = (i2-bb_rect(1))/bb_h;
    cx2 = (j2-bb_rect(2))/bb_w;
    mask2 = exp(-0.5/blob_std.^2*((yy-cy2).^2 + (xx-cx2).^2));

    M(:,:,:,end+1) = cat(3,im2uint8(mask1),im2uint8(mask2),im2uint8(I_ROI));
    P1(:,:,:,end+1) = I_P1;
    P2(:,:,:,end+1) = I_P2;
    BB(:,:,:,end+1) = I_BB;
    
    if opts.viz
        subplot(3,2,1); showim(I); axis image;
        hold on;
        plot(j1,i1,'rO');
        plot(j2,i2,'gO');
        rectangle('Position',[rect1(2) rect1(1), rect1(4)-rect1(2), rect1(3)-rect1(1)]);
        rectangle('Position',[rect2(2) rect2(1), rect2(4)-rect2(2), rect2(3)-rect2(1)]);
        rectangle('Position',[bb_rect(2) bb_rect(1), bb_rect(4)-bb_rect(2), bb_rect(3)-bb_rect(1)]);
        hold off;
        subplot(3,2,2); showim(I_ROI);
        subplot(3,2,3); showim(mask1); title('point1')
        subplot(3,2,4); showim(mask2); title('point2');
        subplot(3,2,5); showim(cat(2,I_P1,I_P2)); title('P1P2');
        subplot(3,2,6); showim(I_BB); title('BB');
        drawnow;
    end
end

M = M(:,:,:,2:end);
P1 = P1(:,:,:,2:end);
P2 = P2(:,:,:,2:end);
BB = BB(:,:,:,2:end);